@@ -1206,75 +1206,6 @@ class ThreadTests(BaseTestCase):
         self.assertEqual(out, b'ok')
         self.assertEqual(err, b'')
 
-    @cpython_only
-    def test_finalize_daemon_thread_hang(self):
-        if support.check_sanitizer(thread=True, memory=True):
-            # the thread running `time.sleep(100)` below will still be alive
-            # at process exit
-            self.skipTest(
-                    "https://github.com/python/cpython/issues/124878 - Known"
-                    " race condition that TSAN identifies.")
-        # gh-87135: tests that daemon threads hang during finalization
-        script = textwrap.dedent('''
-            import os
-            import sys
-            import threading
-            import time
-            import _testcapi
-
-            lock = threading.Lock()
-            lock.acquire()
-            thread_started_event = threading.Event()
-            def thread_func():
-                try:
-                    thread_started_event.set()
-                    _testcapi.finalize_thread_hang(lock.acquire)
-                finally:
-                    # Control must not reach here.
-                    os._exit(2)
-
-            t = threading.Thread(target=thread_func)
-            t.daemon = True
-            t.start()
-            thread_started_event.wait()
-            # Sleep to ensure daemon thread is blocked on `lock.acquire`
-            #
-            # Note: This test is designed so that in the unlikely case that
-            # `0.1` seconds is not sufficient time for the thread to become
-            # blocked on `lock.acquire`, the test will still pass, it just
-            # won't be properly testing the thread behavior during
-            # finalization.
-            time.sleep(0.1)
-
-            def run_during_finalization():
-                # Wake up daemon thread
-                lock.release()
-                # Sleep to give the daemon thread time to crash if it is going
-                # to.
-                #
-                # Note: If due to an exceptionally slow execution this delay is
-                # insufficient, the test will still pass but will simply be
-                # ineffective as a test.
-                time.sleep(0.1)
-                # If control reaches here, the test succeeded.
-                os._exit(0)
-
-            # Replace sys.stderr.flush as a way to run code during finalization
-            orig_flush = sys.stderr.flush
-            def do_flush(*args, **kwargs):
-                orig_flush(*args, **kwargs)
-                if not sys.is_finalizing:
-                    return
-                sys.stderr.flush = orig_flush
-                run_during_finalization()
-
-            sys.stderr.flush = do_flush
-
-            # If the follow exit code is retained, `run_during_finalization`
-            # did not run.
-            sys.exit(1)
-        ''')
-        assert_python_ok("-c", script)
 
 class ThreadJoinOnShutdown(BaseTestCase):
 
@@ -2104,110 +2035,6 @@ class MiscTestCase(unittest.TestCase):
         support.check__all__(self, threading, ('threading', '_thread'),
                              extra=extra, not_exported=not_exported)
 
-    @unittest.skipUnless(hasattr(_thread, 'set_name'), "missing _thread.set_name")
-    @unittest.skipUnless(hasattr(_thread, '_get_name'), "missing _thread._get_name")
-    def test_set_name(self):
-        # set_name() limit in bytes
-        truncate = getattr(_thread, "_NAME_MAXLEN", None)
-        limit = truncate or 100
-
-        tests = [
-            # test short ASCII name
-            "CustomName",
-
-            # test short non-ASCII name
-            "namé€",
-
-            # embedded null character: name is truncated
-            # at the first null character
-            "embed\0null",
-
-            # Test long ASCII names (not truncated)
-            "x" * limit,
-
-            # Test long ASCII names (truncated)
-            "x" * (limit + 10),
-
-            # Test long non-ASCII name (truncated)
-            "x" * (limit - 1) + "é€",
-
-            # Test long non-BMP names (truncated) creating surrogate pairs
-            # on Windows
-            "x" * (limit - 1) + "\U0010FFFF",
-            "x" * (limit - 2) + "\U0010FFFF" * 2,
-            "x" + "\U0001f40d" * limit,
-            "xx" + "\U0001f40d" * limit,
-            "xxx" + "\U0001f40d" * limit,
-            "xxxx" + "\U0001f40d" * limit,
-        ]
-        if os_helper.FS_NONASCII:
-            tests.append(f"nonascii:{os_helper.FS_NONASCII}")
-        if os_helper.TESTFN_UNENCODABLE:
-            tests.append(os_helper.TESTFN_UNENCODABLE)
-
-        if sys.platform.startswith("sunos"):
-            encoding = "utf-8"
-        else:
-            encoding = sys.getfilesystemencoding()
-
-        def work():
-            nonlocal work_name
-            work_name = _thread._get_name()
-
-        for name in tests:
-            if not support.MS_WINDOWS:
-                encoded = name.encode(encoding, "replace")
-                if b'\0' in encoded:
-                    encoded = encoded.split(b'\0', 1)[0]
-                if truncate is not None:
-                    encoded = encoded[:truncate]
-                if sys.platform.startswith("sunos"):
-                    expected = encoded.decode("utf-8", "surrogateescape")
-                else:
-                    expected = os.fsdecode(encoded)
-            else:
-                size = 0
-                chars = []
-                for ch in name:
-                    if ord(ch) > 0xFFFF:
-                        size += 2
-                    else:
-                        size += 1
-                    if size > truncate:
-                        break
-                    chars.append(ch)
-                expected = ''.join(chars)
-
-                if '\0' in expected:
-                    expected = expected.split('\0', 1)[0]
-
-            with self.subTest(name=name, expected=expected):
-                work_name = None
-                thread = threading.Thread(target=work, name=name)
-                thread.start()
-                thread.join()
-                self.assertEqual(work_name, expected,
-                                 f"{len(work_name)=} and {len(expected)=}")
-
-    @unittest.skipUnless(hasattr(_thread, 'set_name'), "missing _thread.set_name")
-    @unittest.skipUnless(hasattr(_thread, '_get_name'), "missing _thread._get_name")
-    def test_change_name(self):
-        # Change the name of a thread while the thread is running
-
-        name1 = None
-        name2 = None
-        def work():
-            nonlocal name1, name2
-            name1 = _thread._get_name()
-            threading.current_thread().name = "new name"
-            name2 = _thread._get_name()
-
-        thread = threading.Thread(target=work, name="name")
-        thread.start()
-        thread.join()
-        self.assertEqual(name1, "name")
-        self.assertEqual(name2, "new name")
-
 
 class InterruptMainTests(unittest.TestCase):
     def check_interrupt_main_with_signal_handler(self, signum):
